==> open-cluster-management-operator-model-6.0.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/OverridesFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OverridesFluentImpl<A extends OverridesFluent<A>> extends BaseFluent<A> implements OverridesFluent<A>{
  public OverridesFluentImpl() {
  }
  public OverridesFluentImpl(Overrides instance) {
    this.withImagePullPolicy(instance.getImagePullPolicy()); 
  }
  private String imagePullPolicy;
  public String getImagePullPolicy() {
    return this.imagePullPolicy;
  }
  public A withImagePullPolicy(String imagePullPolicy) {
    this.imagePullPolicy=imagePullPolicy; return (A) this;
  }
  public Boolean hasImagePullPolicy() {
    return this.imagePullPolicy != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OverridesFluentImpl that = (OverridesFluentImpl) o;
    if (imagePullPolicy != null ? !imagePullPolicy.equals(that.imagePullPolicy) :that.imagePullPolicy != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imagePullPolicy,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imagePullPolicy != null) { sb.append("imagePullPolicy:"); sb.append(imagePullPolicy); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-operator-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/OverridesFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OverridesFluentImpl<A extends OverridesFluent<A>> extends BaseFluent<A> implements OverridesFluent<A>{
  public OverridesFluentImpl() {
  }
  public OverridesFluentImpl(Overrides instance) {
    if (instance != null) {
      this.withImagePullPolicy(instance.getImagePullPolicy());
    }
  }
  private String imagePullPolicy;
  public String getImagePullPolicy() {
    return this.imagePullPolicy;
  }
  public A withImagePullPolicy(String imagePullPolicy) {
    this.imagePullPolicy=imagePullPolicy; return (A) this;
  }
  public Boolean hasImagePullPolicy() {
    return this.imagePullPolicy != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OverridesFluentImpl that = (OverridesFluentImpl) o;
    if (!java.util.Objects.equals(imagePullPolicy, that.imagePullPolicy)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imagePullPolicy,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imagePullPolicy != null) { sb.append("imagePullPolicy:"); sb.append(imagePullPolicy); }
    sb.append("}");
    return sb.toString();
  }
  
}
